Module pagination

Module pagination 

Structs

Connection
Raw connection wrapper for deserialization. Can be used directly for custom queries, but most users should use the flattened Page<T> returned by client methods.
Edge
Raw edge wrapper for deserialization.
OffsetPageInfo
Raw offset page info from the API.
Page
Flattened page of results from a Wave connection type.